@@ -1,7 +1,6 @@
 import pickle
 import re
 from functools import partial
-from inspect import iscoroutinefunction
 from itertools import chain
 from typing import Any, Dict, List, Optional, Tuple, Union, cast
 from uuid import UUID
@@ -28,7 +27,8 @@ from starlite.kwargs import KwargsModel
 from starlite.response import Response
 from starlite.signature import get_signature_model
 from starlite.types import AsyncAnyCallable, CacheKeyBuilder, Method
-from starlite.utils import normalize_path
+from starlite.utils import is_async_callable, normalize_path
+from starlite.utils.exception import get_exception_handler
 
 param_match_regex = re.compile(r"{(.*?)}")
 
@@ -134,22 +134,8 @@ class HTTPRoute(BaseRoute):
         if caching_enabled:
             response = await self.get_cached_response(request=request, route_handler=route_handler)
         if not response:
-            response_data = None
-            before_request_handler = route_handler.resolve_before_request()
-            # run the before_request hook handler
-            if before_request_handler:
-                if iscoroutinefunction(before_request_handler):
-                    response_data = await before_request_handler(request)
-                else:
-                    response_data = await run_sync(before_request_handler, request)
-            if not response_data:
-                response_data = await self.get_response_data(
-                    route_handler=route_handler, parameter_model=parameter_model, request=request
-                )
-            response = await route_handler.to_response(
-                app=scope["app"],
-                data=response_data,
-                plugins=request.app.plugins,
+            response = await self.call_handler(
+                scope=scope, request=request, parameter_model=parameter_model, route_handler=route_handler
             )
             # we cache the response instance
             if caching_enabled:
@@ -160,6 +146,40 @@ class HTTPRoute(BaseRoute):
                 )
         await response(scope, receive, send)
 
+    async def call_handler(
+        self, scope: Scope, request: Request, parameter_model: KwargsModel, route_handler: HTTPRouteHandler
+    ) -> Union[Response, StarletteResponse]:
+        """
+        Calls the before request handlers, retrieves any data required for the route handler,
+        and calls the route handler's to_response method.
+
+        This is wrapped in a try except block - and if an exception is raised,
+        it tries to pass it to an appropriate exception handler - if defined.
+        """
+        try:
+            response_data = None
+            before_request_handler = route_handler.resolve_before_request()
+            # run the before_request hook handler
+            if before_request_handler:
+                if is_async_callable(before_request_handler):
+                    response_data = await before_request_handler(request)
+                else:
+                    response_data = await run_sync(before_request_handler, request)
+            if not response_data:
+                response_data = await self.get_response_data(
+                    route_handler=route_handler, parameter_model=parameter_model, request=request
+                )
+            return await route_handler.to_response(
+                app=scope["app"],
+                data=response_data,
+                plugins=request.app.plugins,
+            )
+        except Exception as e:
+            handler = get_exception_handler(route_handler.resolve_exception_handlers(), e)
+            if handler:
+                return handler(request, e)
+            raise e
+
     @staticmethod
     async def get_response_data(route_handler: HTTPRouteHandler, parameter_model: KwargsModel, request: Request) -> Any:
         """
@@ -182,7 +202,7 @@ class HTTPRoute(BaseRoute):
             fn = partial(cast(AnyCallable, route_handler.fn), route_handler.owner, **parsed_kwargs)
         else:
             fn = partial(cast(AnyCallable, route_handler.fn), **parsed_kwargs)
-        if iscoroutinefunction(fn):
+        if is_async_callable(fn):
             return await fn()
         if route_handler.sync_to_thread:
             return await run_sync(fn)
@@ -207,9 +227,11 @@ class HTTPRoute(BaseRoute):
         Retrieves and un-pickles the cached value, if it exists
         """
         cache_config = request.app.cache_config
-        key_builder = cast(CacheKeyBuilder, route_handler.cache_key_builder or cache_config.cache_key_builder)  # type: ignore[misc]
+        key_builder = cast(
+            CacheKeyBuilder, route_handler.cache_key_builder or cache_config.cache_key_builder  # type: ignore[misc]
+        )
         cache_key = key_builder(request)
-        if iscoroutinefunction(cache_config.backend.get):
+        if is_async_callable(cache_config.backend.get):
             cached_value = await cache_config.backend.get(cache_key)
         else:
             cached_value = cache_config.backend.get(cache_key)
@@ -225,11 +247,13 @@ class HTTPRoute(BaseRoute):
         Pickles and caches a response object
         """
         cache_config = request.app.cache_config
-        key_builder = cast(CacheKeyBuilder, route_handler.cache_key_builder or cache_config.cache_key_builder)  # type: ignore[misc]
+        key_builder = cast(
+            CacheKeyBuilder, route_handler.cache_key_builder or cache_config.cache_key_builder  # type: ignore[misc]
+        )
         cache_key = key_builder(request)
         expiration = route_handler.cache if not isinstance(route_handler.cache, bool) else cache_config.expiration
         pickled_response = pickle.dumps(response, pickle.HIGHEST_PROTOCOL)
-        if iscoroutinefunction(cache_config.backend.set):
+        if is_async_callable(cache_config.backend.set):
             await cache_config.backend.set(cache_key, pickled_response, expiration)
         else:
             cache_config.backend.set(cache_key, pickled_response, expiration)
